@@ -60,6 +60,7 @@
 #include "desktop.h"
 #include "kcustommenu.h"
 #include "kdesktopsettings.h"
+#include "lockeng.h"
 
 #include <netwm.h>
 #include <X11/X.h>
@@ -71,26 +72,17 @@ KRootWm * KRootWm::s_rootWm = 0;
 
 extern TQCString kdesktop_name, kicker_name, twin_name;
 
-KRootWm::KRootWm(KDesktop* _desktop) : TQObject(_desktop), startup(FALSE)
+KRootWm::KRootWm(SaverEngine* _saver, KDesktop* _desktop) : TQObject(_desktop), startup(FALSE)
 {
-  m_helperThread = new TQEventLoopThread;
-  m_helperThread->start();
-  m_threadHelperObject = new KRootWmThreadHelperObject;
-  m_threadHelperObject->moveToThread(m_helperThread);
-  connect(this, TQT_SIGNAL(terminateHelperThread()), m_threadHelperObject, TQT_SLOT(terminateThread()));
-  connect(this, TQT_SIGNAL(asyncLock()), m_threadHelperObject, TQT_SLOT(slotLock()));
-  connect(this, TQT_SIGNAL(asyncLockAndDoNewSession()), m_threadHelperObject, TQT_SLOT(lockAndDoNewSession()));
-  connect(this, TQT_SIGNAL(asyncSlotSessionActivated(int)), m_threadHelperObject, TQT_SLOT(slotSessionActivated(int)));
-
   s_rootWm = this;
   m_actionCollection = new TDEActionCollection(_desktop, this, "KRootWm::m_actionCollection");
+  m_pSaver = _saver;
   m_pDesktop = _desktop;
   m_bDesktopEnabled = (m_pDesktop->iconView() != 0);
   customMenu1 = 0;
   customMenu2 = 0;
   m_configDialog = 0;
 
-
   // Creates the new menu
   menuBar = 0; // no menubar yet
   menuNew = 0;
@@ -224,11 +216,6 @@ KRootWm::KRootWm(KDesktop* _desktop) : TQObject(_desktop), startup(FALSE)
 
 KRootWm::~KRootWm()
 {
-  terminateHelperThread();
-  m_helperThread->wait();
-  delete m_threadHelperObject;
-  delete m_helperThread;
-
   delete m_actionCollection;
   delete desktopMenu;
   delete windowListMenu;
@@ -836,7 +823,7 @@ void KRootWm::slotCascadeWindows() {
 
 
 void KRootWm::slotLock() {
-	asyncLock();
+	m_pSaver->lockScreen();
 }
 
 
@@ -880,39 +867,10 @@ void KRootWm::slotPopulateSessions()
         }
 }
 
-void KRootWmThreadHelperObject::terminateThread() {
-	TQEventLoop* eventLoop = TQApplication::eventLoop();
-	if (eventLoop) {
-		eventLoop->exit(0);
-	}
-}
-
-void KRootWmThreadHelperObject::slotLock() {
-	// Block here until lock is complete
-	// If this is not done the desktop of the locked session will be shown after VT switch until the lock fully engages!
-	// Force remote call to ensure that blocking is enforced even though this call is being made from inside the kdesktop_name application...
-	// If this is not done DCOP will translate the call into a send and the desktop of the locked session will be shown after VT switch as above
-	system("dcop kdesktop KScreensaverIface lock");
-}
-
-void KRootWmThreadHelperObject::lockAndDoNewSession() {
-	// Block here until lock is complete
-	// If this is not done the desktop of the locked session will be shown after VT switch until the lock fully engages!
-	// Force remote call to ensure that blocking is enforced even though this call is being made from inside the kdesktop_name application...
-	// If this is not done DCOP will translate the call into a send and the desktop of the locked session will be shown after VT switch as above
-	if (system("dcop kdesktop KScreensaverIface lock") == 0) {
-		DM().startReserve();
-	}
-}
-
-void KRootWmThreadHelperObject::slotSessionActivated(int vt) {
-	DM().lockSwitchVT( vt );
-}
-
 void KRootWm::slotSessionActivated( int ent )
 {
     if (ent > 0 && !sessionsMenu->isItemChecked( ent )) {
-        asyncSlotSessionActivated( ent );
+        m_pSaver->lockScreenAndSwitchSession(ent);
     }
 }
 
@@ -950,7 +908,7 @@ void KRootWm::doNewSession( bool lock )
         return;
 
     if (lock) {
-        asyncLockAndDoNewSession();
+        m_pSaver->lockScreenAndDoNewSession();
     }
     else {
         DM().startReserve();
