@@ -334,9 +334,13 @@ float * FITSViewer::loadData(const char *filename, float *buffer)
    case 32:
    for (int i=0; i < totalCount ; i++)
     {
-    FITS_GETBITPIX32(tempData, pixval_32);
     //pixval_32 = ntohl(pixval_32);
-    if (isnan(pixval_32)) pixval_32 = 0;
+    if (fits_nan_32(tempData)) {
+        pixval_32 = 0;
+    }
+    else {
+        FITS_GETBITPIX32(tempData, pixval_32);
+    }
     buffer[i] = pixval_32;
     tempData+=4;
    }
