@@ -542,7 +542,7 @@ void AppWizardDialog::accept()
 	m_pCurrentAppInfo->dirList.prepend( baseDir );
 
 	// This is too silly for words, but it's either this or reimplementing FileTemplate
-	TQString tempProjectDomSource = "<!DOCTYPE tdevelop><tdevelop><general><author>%1</author><email>%2</email><version>%3</version></general></tdevelop>";
+	TQString tempProjectDomSource = "<!DOCTYPE kdevelop><kdevelop><general><author>%1</author><email>%2</email><version>%3</version></general></kdevelop>";
 	tempProjectDomSource = tempProjectDomSource.arg( author_edit->text() ).arg( email_edit->text() ).arg( version_edit->text() );
 	TQDomDocument tempProjectDom;
 	tempProjectDom.setContent( tempProjectDomSource );
@@ -999,7 +999,7 @@ ApplicationInfo *AppWizardDialog::templateForItem(TQListViewItem *item)
 
 void AppWizardDialog::openAfterGeneration()
 {
-	TQString projectFile( finalLoc_label->text() + "/" + appname_edit->text().lower() + ".tdevelop" );
+	TQString projectFile( finalLoc_label->text() + "/" + appname_edit->text().lower() + ".kdevelop" );
 
 	// Read the DOM of the newly created project
 	TQFile file( projectFile );
